@@ -17,19 +17,18 @@ typedef struct Isotope2 Isotope2;
 struct Isotope{
     char symbol[MAX_NAME_SIZE];
     char isotope[MAX_NAME_SIZE];
-    double mass;
     double abundance;
+    double mass;
 };
 
 struct Isotope2{
     char symbol[MAX_NAME_SIZE];
     char isotope[MAX_NAME_SIZE];
-    double mass;
+    size_t amount;
     double abundance;
-    int element_nr;
-    int iso_nr;
-    int iso_e_nr;
-    int amount;
+    double mass;
+    unsigned short element_nr;
+    unsigned short iso_e_nr;
 };
 
 int set_isotope(Isotope* isotope, char* symbol, char* iso_name, double mass, double abundance);
